import QtQuick
import QtQuick3D

Window {
    width: 1024
    height: 768
    visible: true
    title: "Compressed texture vs QImage"

    Item {
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.verticalCenter
        }

        Row {
            anchors.centerIn: parent

            Column {
                Text {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: "QtQuick: PNG"
                }

                Image {
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "qrc:/gauge_pattern_mask.png"
                }
            }

            Column {
                Text {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: "QtQuick: BC3 in KTX"
                }

                Image {
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "qrc:/gauge_pattern_mask.ktx"
                }
            }
	    
            Column {
                Text {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: "QtQuick: BC3 in KTX with mirrorVertically: true"
                }

                Image {
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "qrc:/gauge_pattern_mask.ktx"
                    mirrorVertically: true
                }
            }
        }
    }

    View3D {
        id: view3D

        anchors {
            left: parent.left
            right: parent.right
            top: parent.verticalCenter
            bottom: parent.bottom
        }
        environment: sceneEnvironment

        SceneEnvironment {
            id: sceneEnvironment

            antialiasingMode: SceneEnvironment.MSAA
            antialiasingQuality: SceneEnvironment.High
        }

        Node {
            id: scene

            DirectionalLight {
                id: directionalLight
            }

            PerspectiveCamera {
                id: camera
                z: 350
            }

            Model {
                id: planePng

                x: -100
                z: 220
                source: "#Rectangle"
                materials: materialPng

                DefaultMaterial {
                    id: materialPng

                    diffuseMap: texturePng

                    Texture {
                        id: texturePng

                        source: "qrc:/gauge_pattern_mask.png"
                    }
                }

            }

            Model {
                id: planeComp

                x: 0
                z: 220
                source: "#Rectangle"
                materials: materialComp

                DefaultMaterial {
                    id: materialComp

                    diffuseMap: textureComp

                    Texture {
                        id: textureComp
                        //flipV: true

                        source: "qrc:/gauge_pattern_mask.ktx"
                    }
                }
            }

            Model {
                id: planeCompFlipped

                x: 100
                z: 220
                source: "#Rectangle"
                materials: materialCompFlipped

                DefaultMaterial {
                    id: materialCompFlipped

                    diffuseMap: textureCompFlipped

                    Texture {
                        id: textureCompFlipped
                        flipV: true

                        source: "qrc:/gauge_pattern_mask.ktx"
                    }
                }
            }

            Node {
                x: -300
                y: 180

                Text {
                    text: "QtQuick3D: PNG"
                    font.pixelSize: 15
                }
            }

            Node {
                x: -50
                y: 180

                Text {
                    text: "QtQuick3D: BC3 in KTX"
                    font.pixelSize: 15
                }
            }

            Node {
                x: 150
                y: 180

                Text {
                    text: "QtQuick3D: BC3 in KTX with flipV: true"
                    font.pixelSize: 15
                }
            }
        }
    }
}
